#!/usr/bin/env python3.8
# coding:utf-8
# Copyright (C) 2024 All rights reserved.
# FILENAME:    ~~/tests/bench_requests.py
# VERSION: 	   0.1.0
# CREATED: 	   2024-03-21 16:55
# AUTHOR: 	   Sitt Guruvanich <aekazitt+github@gmail.com>
# DESCRIPTION:
#
# HISTORY:
# *************************************************************

### Third-party packages ###
from requests import Response, get
from pytest import mark

### Local modules ###
from tests import *


@mark.requests
def test_requests_get_json_endpoint() -> None:
  for _ in range(1_000):
    response: Response = get(f"{ TEST_ENDPOINT }/json")
    assert response.json() == {"detail": "OK", "status": 200}


@mark.requests
def test_requests_get_orjson_endpoint() -> None:
  for _ in range(1_000):
    response: Response = get(f"{ TEST_ENDPOINT }/orjson")
    assert response.json() == {"detail": "OK", "status": 200}


@mark.requests
def test_requests_get_plaintext_endpoint() -> None:
  for _ in range(1_000):
    response: Response = get(f"{ TEST_ENDPOINT }/plaintext")
    assert response.text == "OK"



#!/usr/bin/env python3.8
# coding:utf-8
# Copyright (C) 2024 All rights reserved.
# FILENAME:    ~~/tests/__init__.py
# VERSION: 	   0.1.0
# CREATED: 	   2024-03-21 13:31
# AUTHOR: 	   Sitt Guruvanich <aekazitt+github@gmail.com>
# DESCRIPTION:
#
# HISTORY:
# *************************************************************

### Standard packages ###
from multiprocessing import Process
from time import sleep
from typing import Generator

### Third-party packages ###
from fastapi import FastAPI
from fastapi.responses import JSONResponse, PlainTextResponse, ORJSONResponse
from pytest import fixture
from uvicorn import run

TEST_HOST: str = "localhost"
TEST_PORT: int = 6969
TEST_ENDPOINT: str = f"http://{ TEST_HOST }:{ TEST_PORT }"


def run_test_server() -> None:
  app: FastAPI = FastAPI()

  @app.get("/plaintext", response_class=PlainTextResponse)
  async def plaintext_endpoint() -> str:
    return "OK"

  @app.get("/json", response_class=JSONResponse)
  async def json_endpoint() -> dict:
    return {"detail": "OK", "status": 200}

  @app.get("/orjson", response_class=ORJSONResponse)
  async def orjson_endpoint() -> dict:
    return {"detail": "OK", "status": 200}

  run(app, host="localhost", port=6969)


@fixture(scope="session", autouse=True)
def setup_teardown_api_server() -> Generator:
  """
  Sets up a FastAPI server with a generic get-endpoint

  ---
  :returns: Generator
  """
  process: Process = Process(daemon=True, target=run_test_server)
  process.start()
  sleep(0.5)  # setup-delay
  yield
  process.terminate()


__all__ = ("TEST_ENDPOINT", "setup_teardown_api_server")



#!/usr/bin/env python3.8
# coding:utf-8
# Copyright (C) 2024 All rights reserved.
# FILENAME:    ~~/tests/bench_aiohttp.py
# VERSION: 	   0.1.0
# CREATED: 	   2024-03-21 16:58
# AUTHOR: 	   Sitt Guruvanich <aekazitt+github@gmail.com>
# DESCRIPTION:
#
# HISTORY:
# *************************************************************

### Third-party packages ###
from aiohttp import ClientSession
from pytest import mark

### Local modules ###
from tests import *


@mark.aiohttp
@mark.asyncio
async def test_aiohttp_get_json_endpoint() -> None:
  for _ in range(1_000):
    async with ClientSession() as session:
      async with session.get(f"{ TEST_ENDPOINT }/json") as response:
        assert await response.json() == {"detail": "OK", "status": 200}


@mark.aiohttp
@mark.asyncio
async def test_aiohttp_get_orjson_endpoint() -> None:
  for _ in range(1_000):
    async with ClientSession() as session:
      async with session.get(f"{ TEST_ENDPOINT }/orjson") as response:
        assert await response.json() == {"detail": "OK", "status": 200}


@mark.aiohttp
@mark.asyncio
async def test_aiohttp_get_plaintext_endpoint() -> None:
  for _ in range(1_000):
    async with ClientSession() as session:
      async with session.get(f"{ TEST_ENDPOINT }/plaintext") as response:
        assert await response.text() == "OK"
